.. SPDX-FileCopyrightText: Copyright © 2024 Idiap Research Institute <contact@idiap.ch>
..
.. SPDX-License-Identifier: GPL-3.0-or-later

.. _mednet.databases.classify:

================
 Classification
================

.. toctree::
   :maxdepth: 1

   hivtb
   indian
   montgomery
   nih_cxr14
   padchest
   shenzhen
   tbpoc
   tbx11k
   visceral
   montgomery_shenzhen
   montgomery_shenzhen_indian
   montgomery_shenzhen_indian_tbx11k
